@@ -1,13 +1,13 @@
 package Object::BlankStr;
 
-our $VERSION = '0.03'; # VERSION
+our $VERSION = '0.04'; # VERSION
 
 use overload q{""} => sub { "" };
 
-sub new { bless(\$_[0], $_[0]) }
+sub new { bless(\"$_[0]", $_[0]) }
 
 1;
-# ABSTRACT: Blank string object
+# ABSTRACT: Object which stringifies to empty string ("")
 
 
 __END__
@@ -15,11 +15,11 @@ __END__
 
 =head1 NAME
 
-Object::BlankStr - Blank string object
+Object::BlankStr - Object which stringifies to empty string ("")
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 SYNOPSIS
 
@@ -27,18 +27,35 @@ version 0.03
 
  die Object::BlankStr->new; # dies without printing anything
 
+ # checking exception the right way
+ eval { die rand() > 0.5 ? Object::BlankStr->new : "blurg" };
+ my $eval_err = $@;
+ if ($eval_err || ref($eval_err)) {
+    ...
+ }
+
+ # checking exception the WRONG way, object is stringified to "" and becomes
+ # false
+ eval { die rand() > 0.5 ? Object::BlankStr->new : "blurg" };
+ if ($@) {
+    ...
+ }
+
 =head1 DESCRIPTION
 
 Object::BlankStr is just an empty object which stringifies to "" (empty string).
-Since it is an object, it has a boolean true value *in some cases*. By *in some
-cases* it means that when object stringification occurs before comparison, the
-truth value becomes false because Perl regards empty string as false.
+Since it is an object, it has a boolean true value (but be careful with
+stringification, see SYNOPSIS).
 
 So far the only case I've found this to be useful is for die()-ing without
 printing anything. If you just use 'die;' or 'die "";' Perl will print the
 default "Died at ..." message. But if you say 'die Object::BlankStr->new;' Perl
 will die without printing anything.
 
+=head1 SEE ALSO
+
+L<Object::NulStr>
+
 =head1 AUTHOR
 
 Steven Haryanto <stevenharyanto@gmail.com>
